@@ -37,7 +37,7 @@ Usage::
     scan_paginator: ScanPaginator = client.get_paginator("scan")
     ```
 """
-from mypy_boto3_dynamodb.client import DynamoDBClient, DynamoDBClient as Client
+from mypy_boto3_dynamodb.client import DynamoDBClient
 from mypy_boto3_dynamodb.paginator import (
     ListBackupsPaginator,
     ListTablesPaginator,
@@ -45,12 +45,14 @@ from mypy_boto3_dynamodb.paginator import (
     QueryPaginator,
     ScanPaginator,
 )
-from mypy_boto3_dynamodb.service_resource import (
-    DynamoDBServiceResource,
-    DynamoDBServiceResource as ServiceResource,
-)
+from mypy_boto3_dynamodb.service_resource import DynamoDBServiceResource
 from mypy_boto3_dynamodb.waiter import TableExistsWaiter, TableNotExistsWaiter
 
+Client = DynamoDBClient
+
+
+ServiceResource = DynamoDBServiceResource
+
 
 __all__ = (
     "Client",
